I'm always impressed by some of the optimisations they find: 0aa403b649 improves readDouble/readFloat in buffers by 200-800% simply by...moving the code to plain javascript binary operations instead of the C++ runtime.
Nobody really cares if your 1 call is 20x slower though. Much better to make it 2x faster when there's 100 calls